from categories.tests.category_import import *
from categories.tests.templatetags import *

__fixtures__ = ['categories.json']
